# Licensing Notice

<img src="https://api.fairsharing.org/img/fairsharing-attribution.svg" alt="FAIRsharing Logo">

FAIRsharing data is redistributed under the CC BY-SA 4.0 license. More
information at https://fairsharing.org/licence.
